@@ -30,7 +30,7 @@ gdk_colormap_get_type (void)
 
   if (!object_type)
     {
-      static const GTypeInfo object_info =
+      const GTypeInfo object_info =
       {
         sizeof (GdkColormapClass),
         (GBaseInitFunc) NULL,
