@@ -24,7 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -82,9 +82,10 @@ struct _GdkKeymapX11
   GdkModifierType group_switch_mask;
   GdkModifierType num_lock_mask;
   GdkModifierType modmap[8];
-  gboolean sun_keypad;
   PangoDirection current_direction;
-  gboolean have_direction;
+  guint sun_keypad      : 1;
+  guint have_direction  : 1;
+  guint caps_lock_state : 1;
   guint current_serial;
 
 #ifdef HAVE_XKB
@@ -118,7 +119,7 @@ gdk_keymap_x11_get_type (void)
 
   if (!object_type)
     {
-      static const GTypeInfo object_info =
+      const GTypeInfo object_info =
 	{
 	  sizeof (GdkKeymapClass),
 	  (GBaseInitFunc) NULL,
@@ -656,12 +657,17 @@ get_num_groups (GdkKeymap *keymap,
       return xkb->ctrls->num_groups;
 }
 
-static void
+static gboolean
 update_direction (GdkKeymapX11 *keymap_x11,
 		  gint          group)
 {
   XkbDescPtr xkb = get_xkb (keymap_x11);
   Atom group_atom;
+  gboolean had_direction;
+  PangoDirection old_direction;
+      
+  had_direction = keymap_x11->have_direction;
+  old_direction = keymap_x11->current_direction;
 
   group_atom = xkb->names->groups[group];
 
@@ -672,6 +678,21 @@ update_direction (GdkKeymapX11 *keymap_x11,
       keymap_x11->current_group_atom = group_atom;
       keymap_x11->have_direction = TRUE;
     }
+
+  return !had_direction || old_direction != keymap_x11->current_direction;
+}
+
+static gboolean
+update_lock_state (GdkKeymapX11 *keymap_x11,
+                   gint          locked_mods)
+{
+  gboolean caps_lock_state;
+  
+  caps_lock_state = keymap_x11->caps_lock_state;
+
+  keymap_x11->caps_lock_state = (locked_mods & GDK_LOCK_MASK) != 0;
+  
+  return caps_lock_state != keymap_x11->caps_lock_state;
 }
 
 /* keep this in sync with the XkbSelectEventDetails() call 
@@ -687,16 +708,12 @@ _gdk_keymap_state_changed (GdkDisplay *display,
   if (display_x11->keymap)
     {
       GdkKeymapX11 *keymap_x11 = GDK_KEYMAP_X11 (display_x11->keymap);
-      gboolean had_direction;
-      PangoDirection direction;
       
-      had_direction = keymap_x11->have_direction;
-      direction = keymap_x11->current_direction;
-      
-      update_direction (keymap_x11, XkbStateGroup (&xkb_event->state));
-      
-      if (!had_direction || direction != keymap_x11->current_direction)
-	g_signal_emit_by_name (keymap_x11, "direction_changed");      
+      if (update_direction (keymap_x11, XkbStateGroup (&xkb_event->state)))
+	g_signal_emit_by_name (keymap_x11, "direction-changed");      
+
+      if (update_lock_state (keymap_x11, xkb_event->state.locked_mods))
+	g_signal_emit_by_name (keymap_x11, "state-changed");      
     }
 }
 
@@ -792,6 +809,29 @@ gdk_keymap_have_bidi_layouts (GdkKeymap *keymap)
     return FALSE;
 }
 
+/**
+ * gdk_keymap_get_caps_lock_state:
+ * @keymap: a #GdkKeymap
+ *
+ * Returns whether the Caps Lock modifer is locked. 
+ *
+ * Returns: %TRUE if Caps Lock is on
+ *
+ * Since: 2.16
+ */
+gboolean
+gdk_keymap_get_caps_lock_state (GdkKeymap *keymap)
+{
+  GdkKeymapX11 *keymap_x11;
+  
+  keymap = GET_EFFECTIVE_KEYMAP (keymap);
+  
+  keymap_x11 = GDK_KEYMAP_X11 (keymap);
+  
+  return keymap_x11->caps_lock_state;
+}
+
+
 /**
  * gdk_keymap_get_entries_for_keyval:
  * @keymap: a #GdkKeymap, or %NULL to use the default keymap
@@ -1158,8 +1198,8 @@ MyEnhancedXkbTranslateKeyCode(register XkbDescPtr     xkb,
                               register unsigned int   mods,
                               unsigned int *          mods_rtrn,
                               KeySym *                keysym_rtrn,
-                              unsigned int *          group_rtrn,
-                              unsigned int *          level_rtrn)
+                              int *                   group_rtrn,
+                              int *                   level_rtrn)
 {
     XkbKeyTypeRec *type;
     int col,nKeyGroups;
@@ -1284,8 +1324,8 @@ translate_keysym (GdkKeymapX11   *keymap_x11,
 		  guint           hardware_keycode,
 		  gint            group,
 		  GdkModifierType state,
-		  guint          *effective_group,
-		  guint          *effective_level)
+		  gint           *effective_group,
+		  gint           *effective_level)
 {
   const KeySym *map = get_keymap (keymap_x11);
   const KeySym *syms = map + (hardware_keycode - keymap_x11->min_keycode) * keymap_x11->keysyms_per_keycode;
@@ -1661,7 +1701,7 @@ _gdk_keymap_key_is_modifier (GdkKeymap *keymap,
     {
       XkbDescRec *xkb = get_xkb (keymap_x11);
       
-      if (xkb->map->modmap[keycode] != 0)
+      if (xkb->map->modmap && xkb->map->modmap[keycode] != 0)
 	return TRUE;
     }
   else
