@@ -17,6 +17,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#error "Only <gtk/gtk.h> can be included directly."
+#endif
+
 #ifndef __GTK_ACCESSIBLE_H__
 #define __GTK_ACCESSIBLE_H__
 
@@ -35,10 +39,9 @@ G_BEGIN_DECLS
 typedef struct _GtkAccessible                GtkAccessible;
 typedef struct _GtkAccessibleClass           GtkAccessibleClass;
 
-  /**
+  /*
    * This object is a thin wrapper, in the GTK+ namespace, for AtkObject
    */
-
 struct _GtkAccessible
 {
   AtkObject parent;
