@@ -303,7 +303,7 @@ gtk_color_selection_class_init (GtkColorSelectionClass *klass)
 						      GTK_PARAM_READWRITE));
   
   color_selection_signals[COLOR_CHANGED] =
-    g_signal_new (I_("color_changed"),
+    g_signal_new (I_("color-changed"),
 		  G_OBJECT_CLASS_TYPE (object_class),
 		  G_SIGNAL_RUN_FIRST,
 		  G_STRUCT_OFFSET (GtkColorSelectionClass, color_changed),
@@ -410,7 +410,7 @@ gtk_color_selection_init (GtkColorSelection *colorsel)
   gtk_label_set_mnemonic_widget (GTK_LABEL (priv->opacity_label),
                                  priv->opacity_slider);
   gtk_scale_set_draw_value (GTK_SCALE (priv->opacity_slider), FALSE);
-  g_signal_connect (adjust, "value_changed",
+  g_signal_connect (adjust, "value-changed",
                     G_CALLBACK (adjustment_changed),
                     GINT_TO_POINTER (COLORSEL_OPACITY));
   gtk_table_attach_defaults (GTK_TABLE (table), priv->opacity_slider, 1, 7, 4, 5); 
@@ -433,7 +433,7 @@ gtk_color_selection_init (GtkColorSelection *colorsel)
   g_signal_connect (priv->hex_entry, "activate",
                     G_CALLBACK (hex_changed), colorsel);
 
-  g_signal_connect (priv->hex_entry, "focus_out_event",
+  g_signal_connect (priv->hex_entry, "focus-out-event",
                     G_CALLBACK (hex_focus_out), colorsel);
 
   gtk_widget_set_tooltip_text (priv->hex_entry,
@@ -918,8 +918,7 @@ color_sample_setup_dnd (GtkColorSelection *colorsel, GtkWidget *sample)
 		       targets, 1,
 		       GDK_ACTION_COPY | GDK_ACTION_MOVE);
   
-  g_signal_connect (sample,
-		    "drag_begin",
+  g_signal_connect (sample, "drag-begin",
 		    G_CALLBACK (color_sample_drag_begin),
 		    colorsel);
   if (sample == priv->cur_sample)
@@ -932,23 +931,44 @@ color_sample_setup_dnd (GtkColorSelection *colorsel, GtkWidget *sample)
 			 targets, 1,
 			 GDK_ACTION_COPY);
       
-      g_signal_connect (sample,
-			"drag_end",
+      g_signal_connect (sample, "drag-end",
 			G_CALLBACK (color_sample_drag_end),
 			colorsel);
     }
   
-  g_signal_connect (sample,
-		    "drag_data_get",
+  g_signal_connect (sample, "drag-data-get",
 		    G_CALLBACK (color_sample_drag_handle),
 		    colorsel);
-  g_signal_connect (sample,
-		    "drag_data_received",
+  g_signal_connect (sample, "drag-data-received",
 		    G_CALLBACK (color_sample_drop_handle),
 		    colorsel);
   
 }
 
+static void
+update_tooltips (GtkColorSelection *colorsel)
+{
+  ColorSelectionPrivate *priv;
+
+  priv = colorsel->private_data;
+
+  if (priv->has_palette == TRUE)
+    {
+      gtk_widget_set_tooltip_text (priv->old_sample,
+                            _("The previously-selected color, for comparison to the color you're selecting now. You can drag this color to a palette entry, or select this color as current by dragging it to the other color swatch alongside."));
+
+      gtk_widget_set_tooltip_text (priv->cur_sample,
+                            _("The color you've chosen. You can drag this color to a palette entry to save it for use in the future."));
+    }
+  else
+    {
+      gtk_widget_set_tooltip_text (priv->old_sample,
+                            _("The previously-selected color, for comparison to the color you're selecting now."));
+
+      gtk_widget_set_tooltip_text (priv->cur_sample,
+                            _("The color you've chosen."));
+    }
+}
 
 static void
 color_sample_new (GtkColorSelection *colorsel)
@@ -966,23 +986,18 @@ color_sample_new (GtkColorSelection *colorsel)
   gtk_box_pack_start (GTK_BOX (priv->sample_area), priv->cur_sample,
 		      TRUE, TRUE, 0);
   
-  g_signal_connect (priv->old_sample, "expose_event",
+  g_signal_connect (priv->old_sample, "expose-event",
 		    G_CALLBACK (color_old_sample_expose),
 		    colorsel);
-  g_signal_connect (priv->cur_sample, "expose_event",
+  g_signal_connect (priv->cur_sample, "expose-event",
 		    G_CALLBACK (color_cur_sample_expose),
 		    colorsel);
   
   color_sample_setup_dnd (colorsel, priv->old_sample);
   color_sample_setup_dnd (colorsel, priv->cur_sample);
 
-  gtk_widget_set_tooltip_text (priv->old_sample,
-                        _("The previously-selected color, for comparison to the color you're selecting now. You can drag this color to a palette entry, or select this color as current by dragging it to the other color swatch alongside."));
+  update_tooltips (colorsel);
 
-
-  gtk_widget_set_tooltip_text (priv->cur_sample,
-                        _("The color you've chosen. You can drag this color to a palette entry to save it for use in the future."));
-  
   gtk_widget_show_all (priv->sample_area);
 }
 
@@ -1072,7 +1087,7 @@ set_focus_line_attributes (GtkWidget *drawing_area,
 
   if (dash_list[0])
     {
-      gint n_dashes = strlen (dash_list);
+      gint n_dashes = strlen ((gchar *)dash_list);
       gdouble *dashes = g_new (gdouble, n_dashes);
       gdouble total_length = 0;
       gdouble dash_offset;
@@ -1270,12 +1285,10 @@ palette_set_color (GtkWidget         *drawing_area,
 			   targets, 1,
 			   GDK_ACTION_COPY | GDK_ACTION_MOVE);
       
-      g_signal_connect (drawing_area,
-			"drag_begin",
+      g_signal_connect (drawing_area, "drag-begin",
 			G_CALLBACK (palette_drag_begin),
 			colorsel);
-      g_signal_connect (drawing_area,
-			"drag_data_get",
+      g_signal_connect (drawing_area, "drag-data-get",
 			G_CALLBACK (palette_drag_handle),
 			colorsel);
       
@@ -1543,19 +1556,19 @@ palette_new (GtkColorSelection *colorsel)
                          | GDK_ENTER_NOTIFY_MASK
                          | GDK_LEAVE_NOTIFY_MASK);
   
-  g_signal_connect (retval, "expose_event",
+  g_signal_connect (retval, "expose-event",
 		    G_CALLBACK (palette_expose), colorsel);
-  g_signal_connect (retval, "button_press_event",
+  g_signal_connect (retval, "button-press-event",
 		    G_CALLBACK (palette_press), colorsel);
-  g_signal_connect (retval, "button_release_event",
+  g_signal_connect (retval, "button-release-event",
 		    G_CALLBACK (palette_release), colorsel);
-  g_signal_connect (retval, "enter_notify_event",
+  g_signal_connect (retval, "enter-notify-event",
 		    G_CALLBACK (palette_enter), colorsel);
-  g_signal_connect (retval, "leave_notify_event",
+  g_signal_connect (retval, "leave-notify-event",
 		    G_CALLBACK (palette_leave), colorsel);
-  g_signal_connect (retval, "key_press_event",
+  g_signal_connect (retval, "key-press-event",
 		    G_CALLBACK (palette_activate), colorsel);
-  g_signal_connect (retval, "popup_menu",
+  g_signal_connect (retval, "popup-menu",
 		    G_CALLBACK (palette_popup), colorsel);
   
   gtk_drag_dest_set (retval,
@@ -1565,9 +1578,9 @@ palette_new (GtkColorSelection *colorsel)
 		     targets, 1,
 		     GDK_ACTION_COPY);
   
-  g_signal_connect (retval, "drag_end",
+  g_signal_connect (retval, "drag-end",
                     G_CALLBACK (palette_drag_end), NULL);
-  g_signal_connect (retval, "drag_data_received",
+  g_signal_connect (retval, "drag-data-received",
                     G_CALLBACK (palette_drop_handle), colorsel);
 
   gtk_widget_set_tooltip_text (retval,
@@ -1800,10 +1813,10 @@ mouse_press (GtkWidget      *invisible,
   if (event->type == GDK_BUTTON_PRESS &&
       event->button == 1)
     {
-      g_signal_connect (invisible, "motion_notify_event",
+      g_signal_connect (invisible, "motion-notify-event",
                         G_CALLBACK (mouse_motion),
                         data);
-      g_signal_connect (invisible, "button_release_event",
+      g_signal_connect (invisible, "button-release-event",
                         G_CALLBACK (mouse_release),
                         data);
       g_signal_handlers_disconnect_by_func (invisible,
@@ -1877,9 +1890,9 @@ get_screen_color (GtkWidget *button)
   priv->grab_time = time;
   priv->has_grab = TRUE;
   
-  g_signal_connect (priv->dropper_grab_widget, "button_press_event",
+  g_signal_connect (priv->dropper_grab_widget, "button-press-event",
                     G_CALLBACK (mouse_press), colorsel);
-  g_signal_connect (priv->dropper_grab_widget, "key_press_event",
+  g_signal_connect (priv->dropper_grab_widget, "key-press-event",
                     G_CALLBACK (key_press), colorsel);
 }
 
@@ -2043,23 +2056,23 @@ make_label_spinbutton (GtkColorSelection *colorsel,
 
   if (channel_type == COLORSEL_HUE)
     {
-      adjust = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 360.0, 1.0, 1.0, 1.0));
+      adjust = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 360.0, 1.0, 1.0, 0.0));
     }
   else if (channel_type == COLORSEL_SATURATION ||
 	   channel_type == COLORSEL_VALUE)
     {
-      adjust = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 100.0, 1.0, 1.0, 1.0));
+      adjust = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 100.0, 1.0, 1.0, 0.0));
     }
   else
     {
-      adjust = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 255.0, 1.0, 1.0, 1.0));
+      adjust = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 255.0, 1.0, 1.0, 0.0));
     }
   g_object_set_data (G_OBJECT (adjust), I_("COLORSEL"), colorsel);
   *spinbutton = gtk_spin_button_new (adjust, 10.0, 0);
 
   gtk_widget_set_tooltip_text (*spinbutton, tooltip);  
 
-  g_signal_connect (adjust, "value_changed",
+  g_signal_connect (adjust, "value-changed",
                     G_CALLBACK (adjustment_changed),
                     GINT_TO_POINTER (channel_type));
   label = gtk_label_new_with_mnemonic (text);
@@ -2370,7 +2383,9 @@ gtk_color_selection_set_has_palette (GtkColorSelection *colorsel,
 	gtk_widget_show (priv->palette_frame);
       else
 	gtk_widget_hide (priv->palette_frame);
-      
+
+      update_tooltips (colorsel);
+
       g_object_notify (G_OBJECT (colorsel), "has-palette");
     }
 }
@@ -2509,8 +2524,8 @@ gtk_color_selection_get_current_alpha (GtkColorSelection *colorsel)
  * @color: an array of 4 #gdouble to fill in with the current color.
  *
  * Sets @color to be the current color in the GtkColorSelection widget.
- * 
- * This function is deprecated, use gtk_color_selection_get_current_color() instead.
+ *
+ * Deprecated: Use gtk_color_selection_get_current_color() instead.
  **/
 void
 gtk_color_selection_get_color (GtkColorSelection *colorsel,
@@ -2826,9 +2841,8 @@ gtk_color_selection_palette_to_string (const GdkColor *colors,
  *
  * Return value: the previous change palette hook (that was replaced).
  *
- * Deprecated: 2.4: This function is deprecated in favor of 
- * gtk_color_selection_set_change_palette_with_screen_hook(), and does
- * not work in multihead environments.
+ * Deprecated: 2.4: This function does not work in multihead environments.
+ *     Use gtk_color_selection_set_change_palette_with_screen_hook() instead. 
  * 
  **/
 GtkColorSelectionChangePaletteFunc
