@@ -47,16 +47,21 @@
  *
  */
 
+#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#error "Only <gtk/gtk.h> can be included directly."
+#endif
+
 #ifndef __GTK_TEXT_TAG_H__
 #define __GTK_TEXT_TAG_H__
 
-#include <glib-object.h>
+
 #include <gdk/gdk.h>
 #include <gtk/gtkenums.h>
 
 /* Not needed, retained for compatibility -Yosh */
 #include <gtk/gtkobject.h>
 
+
 G_BEGIN_DECLS
 
 typedef struct _GtkTextIter GtkTextIter;
@@ -125,8 +130,11 @@ struct _GtkTextTag
   guint editable_set : 1;
   guint language_set : 1;
   guint pg_bg_color_set : 1;
+
+  /* Whether these margins accumulate or override */
+  guint accumulative_margin : 1;
+
   guint pad1 : 1;
-  guint pad2 : 1;
 };
 
 struct _GtkTextTagClass
@@ -270,7 +278,7 @@ GtkTextAttributes* gtk_text_attributes_copy        (GtkTextAttributes *src);
 void               gtk_text_attributes_copy_values (GtkTextAttributes *src,
                                                     GtkTextAttributes *dest);
 void               gtk_text_attributes_unref       (GtkTextAttributes *values);
-GtkTextAttributes* gtk_text_attributes_ref         (GtkTextAttributes *values);
+GtkTextAttributes *gtk_text_attributes_ref         (GtkTextAttributes *values);
 
 GType              gtk_text_attributes_get_type    (void) G_GNUC_CONST;
 
