@@ -891,7 +891,7 @@ gtk_tree_model_types_get_type (void)
 
   if (!model_types_type)
     {
-      static const GTypeInfo model_types_info =
+      const GTypeInfo model_types_info =
       {
         sizeof (GtkTreeModelTypesClass),
 	NULL,		/* base_init */
@@ -904,7 +904,7 @@ gtk_tree_model_types_get_type (void)
         (GInstanceInitFunc) gtk_tree_model_types_init
       };
 
-      static const GInterfaceInfo tree_model_info =
+      const GInterfaceInfo tree_model_info =
       {
 	(GInterfaceInitFunc) gtk_tree_model_types_tree_model_init,
 	NULL,
@@ -1050,7 +1050,7 @@ gtk_real_model_types_get_value (GtkTreeModel *tree_model,
         
         g_value_init (value, G_TYPE_STRING);
 
-        str = g_strdup_printf ("%ld", type);
+        str = g_strdup_printf ("%ld", (long int) type);
         g_value_set_string (value, str);
         g_free (str);
       }
@@ -1249,7 +1249,9 @@ gtk_real_model_types_iter_parent (GtkTreeModel *tree_model,
   if (parent == G_TYPE_INVALID)
     {
       if (type > G_TYPE_FUNDAMENTAL_MAX)
-        g_warning ("no parent for %ld %s\n", type, g_type_name (type));
+        g_warning ("no parent for %ld %s\n",
+                   (long int) type,
+                   g_type_name (type));
       return FALSE;
     }
   else
@@ -1264,6 +1266,8 @@ gtk_real_model_types_iter_parent (GtkTreeModel *tree_model,
  * Automated testing
  */
 
+#if 0
+
 static void
 treestore_torture_recurse (GtkTreeStore *store,
                            GtkTreeIter  *root,
@@ -1353,6 +1357,8 @@ treestore_torture_recurse (GtkTreeStore *store,
     }
 }
 
+#endif
+
 static void
 run_automated_tests (void)
 {
